pystagram.graph_api.components.metrics package — pystagram 0.1 documentation

# pystagram.graph_api.components.metrics package

## Submodules

## pystagram.graph_api.components.metrics.album_metrics module

class pystagram.graph_api.components.metrics.album_metrics.AlbumMetrics(value)

  Bases: `Metrics`

  An enumeration.

  CAROUSEL_ALBUM_ENGAGEMENT = 'carousel_album_engagement'
  CAROUSEL_ALBUM_IMPRESSIONS = 'carousel_album_impressions'
  CAROUSEL_ALBUM_REACH = 'carousel_album_reach'
  CAROUSEL_ALBUM_SAVED = 'carousel_album_saved'
  CAROUSEL_ALBUM_VIDEO_VIEWS = 'carousel_album_video_views'

## pystagram.graph_api.components.metrics.base_metrics module

class pystagram.graph_api.components.metrics.base_metrics.BaseMetrics(name, bases, namespace, **kwargs)

  Bases: `ABCMeta`, `EnumMeta`

## pystagram.graph_api.components.metrics.insight_metrics module

class pystagram.graph_api.components.metrics.insight_metrics.InsightMetrics(value)

  Bases: `Metrics`

  An enumeration.

  AUDIENCE_CITY = 'audience_city'
  AUDIENCE_COUNTRY = 'audience_country'
  AUDIENCE_GENDER_AGE = 'audience_gender_age'
  AUDIENCE_LOCALE = 'audience_locale'
  EMAIL_CONTACTS = 'email_contacts'
  FOLLOWER_COUNT = 'follower_count'
  GET_DIRECTIONS_CLICKS = 'get_directions_clicks'
  IMPRESSIONS = 'impressions'
  ONLINE_FOLLOWERS = 'online_followers'
  PHONE_CALL_CLICKS = 'phone_call_clicks'
  PROFILE_VIEWS = 'profile_views'
  REACH = 'reach'
  TEXT_MESSAGE_CLICKS = 'text_message_clicks'
  WEBSITE_CLICKS = 'website_clicks'

## pystagram.graph_api.components.metrics.media_metrics module

class pystagram.graph_api.components.metrics.media_metrics.MediaMetrics(value)

  Bases: `Metrics`

  An enumeration.

  ENGAGEMENT = 'engagement'
  IMPRESSIONS = 'impressions'
  REACH = 'reach'
  SAVED = 'saved'
  VIDEO_VIEWS = 'video_views'

## pystagram.graph_api.components.metrics.metrics module

class pystagram.graph_api.components.metrics.metrics.Metrics(value)

  Bases: `str`, `Enum`

  An enumeration.

  classmethod list()

## pystagram.graph_api.components.metrics.reel_metrics module

class pystagram.graph_api.components.metrics.reel_metrics.ReelMetrics(value)

  Bases: `Metrics`

  An enumeration.

  CLIPS_REPLAYS_COUNT = 'clips_replays_count'
  COMMENTS = 'comments'
  IG_REELS_AGGREGATED_ALL_PLAYS_COUNT = 'ig_reels_aggregated_all_plays_count'
  IG_REELS_AVG_WATCH_TIME = 'ig_reels_avg_watch_time'
  IG_REELS_VIDEO_VIEW_TOTAL_TIME = 'ig_reels_video_view_total_time'
  LIKES = 'likes'
  PLAYS = 'plays'
  REACH = 'reach'
  SAVED = 'saved'
  SHARES = 'shares'
  TOTAL_INTERACTIONS = 'total_interactions'

## pystagram.graph_api.components.metrics.story_metrics module

class pystagram.graph_api.components.metrics.story_metrics.StoryMetrics(value)

  Bases: `Metrics`

  An enumeration.

  EXITS = 'exits'
  IMPRESSIONS = 'impressions'
  REACH = 'reach'
  REPLIES = 'replies'
  TAPS_BACK = 'taps_back'
  TAPS_FORWARD = 'taps_forward'

## Module contents